AiClients class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
baseten({String? apiUrl, String? apiKey, String? model, Duration? delay, Logger? logger})
→ BasetenClient
-
-
gemini({String? apiUrl, String? apiKey, String? model, Duration? delay, Logger? logger})
→ GeminiClient
-
-
openAi({String? apiUrl, String? apiKey, String? model, Duration? delay, Logger? logger})
→ OpenAiClient
-
-
together({String? apiUrl, String? apiKey, String? model, Duration? delay, Logger? logger})
→ TogetherClient
-