menu
ai_clients package
documentation
mcp/ai_mcp_client.dart
AiMcpClient class
AiMcpClient class
dark_mode
light_mode
AiMcpClient
class
Constructors
AiMcpClient
({
String
name
=
'Example Client'
,
String
version
=
'1.0.0'
,
bool
enableDebugLogging
=
true
})
Properties
client
↔ Client?
getter/setter pair
enableDebugLogging
→
bool
final
hashCode
→
int
The hash code for this object.
no setter
inherited
name
→
String
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
version
→
String
final
Methods
getTools
(
)
→
Future
<
List
<
Tool
>
>
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sse
(
{
required
Uri
url
})
→
Future
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
ai_clients package
documentation
mcp/ai_mcp_client
AiMcpClient class
ai_mcp_client library